// Copyright (c) 2016, Herman Bergwerf. All rights reserved.
// Use of this source code is governed by an AGPL-3.0-style license
// that can be found in the LICENSE file.

part of molview_messages.standards;

/// Overview
/// ========
/// This is a list of all keys included in the standards library. A key should
/// meet at least one of the requirments listed below to be included in this
/// library.
/// - The key is used across multiple independent databases.
/// - The key is a general purpose identifier that can be generated using an
///   algorithm.
///
/// The keys that are currently included are:
/// - InChiKey
/// - InChi
/// - Canonical SMILES
/// - Isomeric SMILES
/// - CAS Registry Numbert
/// - IUPAC name
/// - PDB code

const classInChiKey = 'inchikey';
const classInChi = 'inchi';
const classCannonicalSmiles = 'canonical_smiles';
const classIsomericSmiles = 'isomeric_smiles';
const classCasRegistryNumber = 'casrn';
const classIupacName = 'iupac_name';
const classPdbCode = 'pdbid';

class InChiKey extends TableKey {
  const InChiKey(KeyRelationType relation)
      : super(DataType.text, classInChiKey, relation);
}

class InChi extends TableKey {
  const InChi(KeyRelationType relation)
      : super(DataType.text, classInChi, relation);
}

class CanonicalSmiles extends TableKey {
  const CanonicalSmiles(KeyRelationType relation)
      : super(DataType.text, classCannonicalSmiles, relation);
}

class IsomericSmiles extends TableKey {
  const IsomericSmiles(KeyRelationType relation)
      : super(DataType.text, classIsomericSmiles, relation);
}

class CasRegistryNumber extends TableKey {
  const CasRegistryNumber(KeyRelationType relation)
      : super(DataType.text, classCasRegistryNumber, relation);
}

class IupacName extends TableKey {
  const IupacName(KeyRelationType relation)
      : super(DataType.text, classIupacName, relation);
}

class PdbCode extends TableKey {
  const PdbCode(KeyRelationType relation)
      : super(DataType.text, classPdbCode, relation);
}
